summaryrefslogtreecommitdiffstats
path: root/src/basket_part.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/basket_part.cpp')
-rw-r--r--src/basket_part.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/basket_part.cpp b/src/basket_part.cpp
index c3f1c8b..ebfefa6 100644
--- a/src/basket_part.cpp
+++ b/src/basket_part.cpp
@@ -36,8 +36,8 @@ typedef KParts::GenericFactory< BasketPart > BasketFactory;
K_EXPORT_COMPONENT_FACTORY( libbasketpart, BasketFactory )
BasketPart::BasketPart( TQWidget *parentWidget, const char *,
- TQObject *tqparent, const char *name, const TQStringList & )
- : KParts::ReadWritePart(tqparent, name)
+ TQObject *parent, const char *name, const TQStringList & )
+ : KParts::ReadWritePart(parent, name)
{
// we need an instance
setInstance( BasketFactory::instance() );
@@ -73,7 +73,7 @@ void BasketPart::setReadWrite(bool rw)
void BasketPart::setModified(bool modified)
{
// in any event, we want our tqparent to do it's thing
ReadWritePart::setModified(modified);
}
@@ -73,7 +73,7 @@ void BasketPart::setReadWrite(bool rw)
void BasketPart::setModified(bool modified)
{
- // in any event, we want our tqparent to do it's thing
+ // in any event, we want our parent to do it's thing
ReadWritePart::setModified(modified);
}